Stan Math Library: stan/math/rev/mat/fun/grad.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
grad.hpp File Reference
`#include <stan/math/prim/mat/fun/Eigen.hpp>`
`#include <stan/math/rev/mat/fun/Eigen_NumTraits.hpp>`
`#include <stan/math/rev/core.hpp>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
void | stan::math::grad (var &v, Eigen::Matrix< var, Eigen::Dynamic, 1 > &x, Eigen::VectorXd &g)
| Propagate chain rule to calculate gradients starting from the specified variable. More...

[ Stan Home Page ] © 2011–2016, Stan Development Team.